@@ -1,6 +1,6 @@
 package Map::Tube::Tokyo::Line::Asakusa;
 
-$Map::Tube::Tokyo::Line::Asakusa::VERSION   = '0.23';
+$Map::Tube::Tokyo::Line::Asakusa::VERSION   = '0.24';
 $Map::Tube::Tokyo::Line::Asakusa::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -14,7 +14,7 @@ Map::Tube::Tokyo::Line::Asakusa - Tokyo Subway Map: Asakusa Line.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 DESCRIPTION
 
@@ -71,13 +71,13 @@ Tokyo Subway Map: Asakusa Line.
 
 =head1 MAP
 
-Tokyo Subway Map: L<Asakusa Line|https://raw.githubusercontent.com/Manwar/Map-Tube-Tokyo/master/maps/Asakusa.png>
+Tokyo Subway Map: L<Asakusa Line|https://raw.githubusercontent.com/manwar/Map-Tube-Tokyo/master/maps/Asakusa.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-Tokyo/master/maps/Asakusa.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-Tokyo/master/maps/Asakusa.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-Tokyo/master/maps/Asakusa.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-Tokyo/master/maps/Asakusa.png"
      alt    = "Tokyo Subway Map: Asakusa Line"
      width  = "700px"
      height = "600px"/>
@@ -91,7 +91,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-Tokyo>
+L<https://github.com/manwar/Map-Tube-Tokyo>
 
 =head1 BUGS
 
