@@ -1,6 +1,6 @@
 package Map::Tube::Tokyo::Line::Chiyoda;
 
-$Map::Tube::Tokyo::Line::Chiyoda::VERSION   = '0.23';
+$Map::Tube::Tokyo::Line::Chiyoda::VERSION   = '0.24';
 $Map::Tube::Tokyo::Line::Chiyoda::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -14,7 +14,7 @@ Map::Tube::Tokyo::Line::Chiyoda - Tokyo Subway Map: Chiyoda Line.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 DESCRIPTION
 
@@ -49,39 +49,46 @@ Tokyo Subway Map: Chiyoda Line.
 
 =over 2
 
-=item * The station "Meiji-jingumae" is also part of Fukutoshin Line.
+=item * The station "Meiji-jingumae" is also part of
+          Fukutoshin Line.
 
-=item * The station "Omote-sando" is also part of Ginza Line
+=item * The station "Omote-sando" is also part of
+          Ginza Line
         | Hanzōmon Line.
 
-=item * The station "Tameike-sanno" is also part of Ginza Line
+=item * The station "Tameike-sanno" is also part of
+          Ginza Line
         | Namboku Line
         | Marunouchi Line.
 
-=item * The station "Kasumigaseki" is also part of HIbiya Line
+=item * The station "Kasumigaseki" is also part of
+          Hibiya Line
         | Marunouchi Line.
 
-=item * The station "Hibiya" is also part of Mita Line
+=item * The station "Hibiya" is also part of
+          Mita Line
         | Hibiya Line.
 
-=item * The station "Otemachi" is also part of Mita Line
+=item * The station "Otemachi" is also part of
+          Mita Line
         | Tōzai Line
         | Hanzōmon Line
         | Marunouchi Line.
 
-=item * The station "Kita-senju" is also part of Hibiya Line.
+=item * The station "Kita-senju" is also part of
+          Hibiya Line.
 
 =back
 
 =head1 MAP
 
-Tokyo Subway Map: L<Chiyoda Line|https://raw.githubusercontent.com/Manwar/Map-Tube-Tokyo/master/maps/Chiyoda.png>
+Tokyo Subway Map: L<Chiyoda Line|https://raw.githubusercontent.com/manwar/Map-Tube-Tokyo/master/maps/Chiyoda.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-Tokyo/master/maps/Chiyoda.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-Tokyo/master/maps/Chiyoda.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-Tokyo/master/maps/Chiyoda.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-Tokyo/master/maps/Chiyoda.png"
      alt    = "Tokyo Subway Map: Chiyoda Line"
      width  = "700px"
      height = "600px"/>
@@ -95,7 +102,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube-Tokyo>
+L<https://github.com/manwar/Map-Tube-Tokyo>
 
 =head1 BUGS
 
